@@ -4,8 +4,8 @@ from meilisearch_fastapi.models.document_info import (  # noqa: F401
     DocumentInfoBatches,
 )
 from meilisearch_fastapi.models.index import (  # noqa: F401
-    AttribugtesForFacetingWithUID,
     AttributesForFaceting,
+    AttributesForFacetingWithUID,
     DisplayedAttributes,
     DisplayedAttributesUID,
     DistinctAttribute,
